pub fn text_len(content: &Value) -> usizeExpand description
The number of characters of text content carries, in either shape.
A string is its own length; an array is the sum of its parts’ text
fields, with the parts that are not text counting for nothing; any other
shape is 0.